package dev.adriankuta.flights.ui.home.components

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import dev.adriankuta.flights.domain.types.AirportInfo
import dev.adriankuta.flights.ui.home.HomeUiState
import java.time.LocalDate

@Composable
internal fun SearchForm(
    uiState: HomeUiState.Success,
    onOriginAirportSelect: (AirportInfo) -> Unit,
    onDestinationAirportSelect: (AirportInfo) -> Unit,
    onDateSelect: (LocalDate) -> Unit,
    onAdultCountChange: (Int) -> Unit,
    onTeenCountChange: (Int) -> Unit,
    onChildCountChange: (Int) -> Unit,
    onSearch: () -> Unit,
    modifier: Modifier = Modifier,
) {
    Column(modifier) {
        AirportDropdown(
            label = "Origin Airport",
            airports = uiState.originAirports,
            selectedAirport = uiState.selectedOriginAirport,
            onAirportSelect = onOriginAirportSelect,
            modifier = Modifier.fillMaxWidth(),
        )

        Spacer(modifier = Modifier.height(16.dp))

        AirportDropdown(
            label = "Destination Airport",
            airports = uiState.destinationAirports,
            selectedAirport = uiState.selectedDestinationAirport,
            onAirportSelect = onDestinationAirportSelect,
            modifier = Modifier.fillMaxWidth(),
            enabled = uiState.selectedOriginAirport != null,
        )

        Spacer(modifier = Modifier.height(16.dp))

        DatePicker(
            label = "Departure Date",
            selectedDate = uiState.selectedDate,
            onDateSelect = onDateSelect,
            modifier = Modifier.fillMaxWidth(),
            enabled = uiState.selectedDestinationAirport != null,
        )

        Spacer(modifier = Modifier.height(16.dp))

        Text("Passengers")

        Spacer(modifier = Modifier.height(8.dp))

        PassengersOptions(uiState, onAdultCountChange, onTeenCountChange, onChildCountChange)

        Spacer(modifier = Modifier.height(24.dp))

        Button(
            onClick = onSearch,
            modifier = Modifier.fillMaxWidth(),
            enabled = uiState.selectedOriginAirport != null && uiState.selectedDestinationAirport != null,
        ) {
            Text("Search Flights")
        }
    }
}
